@@ -13,16 +13,16 @@ def TTSnorm(text, punc = False, unknown = True, lower = True, rule = False ):
     myenv['LD_LIBRARY_PATH'] = A+'/lib'
 
     E=A+"/main"
-    #print(E)
-    # if punc:
-    #     E=E+" -punc"
-    # if unknown:
-    #     E=E+" -unknown"
-    # if lower:
-    #     E=E+" -lower"
-    # if rule:
-    #     E=E+" -rule"
-    subprocess.check_call([E], "-punc", env=myenv, cwd=A)
+    Command = [E]
+    if punc:
+        Command.append(" -punc")
+    if unknown:
+        Command.append(" -unknown")
+    if lower:
+        Command.append(" -lower")
+    if rule:
+        Command.append(" -rule")
+    subprocess.check_call([E], env=myenv, cwd=A)
     
     O=A+"/output.txt"
     with open(O,"r") as fr:
